"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _clientEventbridge = require("@webiny/aws-sdk/client-eventbridge");
var _error = _interopRequireDefault(require("@webiny/error"));
var _api = require("@webiny/api");
var _default = configuration => {
  return new _api.ContextPlugin(context => {
    const client = new _clientEventbridge.EventBridgeClient();
    context.prerenderingServiceClient = {
      async render(tasks) {
        // In this package, rendering is always done through a queue, so this method is almost identical to `queue.add`.
        await sendEvents(renderEvents(tasks));
      },
      async flush(tasks) {
        await sendEvents(flushEvents(tasks));
      },
      queue: {
        async add(tasks) {
          if (!Array.isArray(tasks)) {
            tasks = [tasks];
          }
          const events = [];
          for (const task of tasks) {
            if (task.render) {
              events.push(...renderEvents(task.render));
            }
            if (task.flush) {
              events.push(...flushEvents(task.flush));
            }
          }
          await sendEvents(events);
        },
        async process() {
          // Nothing to do here
          // Processing is done by the SQS queue.
        }
      }
    };
    function renderEvents(tasks) {
      if (!Array.isArray(tasks)) {
        tasks = [tasks];
      }
      return tasks.map(task => ({
        Source: "webiny-api",
        EventBusName: configuration.eventBus,
        DetailType: "RenderPages",
        Detail: JSON.stringify(task)
      }));
    }
    function flushEvents(tasks) {
      if (!Array.isArray(tasks)) {
        tasks = [tasks];
      }
      return tasks.map(task => ({
        Source: "webiny-api",
        EventBusName: configuration.eventBus,
        DetailType: "FlushPages",
        Detail: JSON.stringify(task)
      }));
    }
    async function sendEvents(events) {
      const result = await client.send(new _clientEventbridge.PutEventsCommand({
        Entries: events
      }));
      if (result.FailedEntryCount) {
        throw new _error.default({
          message: "Failed to send some events to the event bus",
          data: {
            entries: result.Entries
          }
        });
      }
    }
  });
};
exports.default = _default;

//# sourceMappingURL=index.js.map